unit uVisitedDirectories;
{$INCLUDE 'Plugin.inc'}

interface

uses
  SysUtils, Classes;

type
  TVisitedDirectories = class
  private
    fList: TStringList;
  protected
    function Normalize(const Directory: string): string;
  public
    constructor Create;
    destructor Destroy; override;
    function Visited(const Directory: string): boolean;
    procedure Enter(const Directory: string);
    procedure Leave;
  end;

implementation

uses
  uSystem;

{ TVisitedDirectories }

constructor TVisitedDirectories.Create;
begin
  inherited Create;
  fList := TStringList.Create;
end;

destructor TVisitedDirectories.Destroy;
begin
  FreeAndNil(fList);
  inherited;
end;

procedure TVisitedDirectories.Enter(const Directory: string);
begin
  fList.Add(Normalize(Directory));
end;

procedure TVisitedDirectories.Leave;
begin
  if fList.Count > 0 then
    fList.Delete(Pred(fList.Count));
end;

function TVisitedDirectories.Normalize(const Directory: string): string;
begin
  Result := AnsiUpperCase(GetRealFileName(ExcludeTrailingPathDelimiter(Directory)));
end;

function TVisitedDirectories.Visited(const Directory: string): boolean;
var
  Dir: string;
  i: integer;
begin
  Result := False;
  Dir := Normalize(Directory);
  for i := 0 to Pred(fList.Count) do
  begin
    if Dir = fList[i] then
    begin
      Result := True;
      Break;
    end;
  end;
end;

end.
